Crate code_split_complexity

Crate code_split_complexity 

Functions

analyze
Walk all source files under root whose extension is in extensions, compute complexity metrics via rust-code-analysis, and annotate Fn, Method, and File nodes in the graph. Returns the number of nodes annotated.
analyze_js
Same as analyze but for JavaScript / TypeScript source files.
analyze_python
Same as analyze but for Python source files.