analyze

Function analyze 

pub fn analyze(root: &Path, builder: &mut GraphBuilder) -> Result<usize>
Walk all source files under root whose extension is in extensions, compute complexity metrics via rust-code-analysis, and annotate Fn, Method, and File nodes in the graph. Returns the number of nodes annotated.